import os
import json

import requests

URL = os.environ.get('N64_API_URL', 'https://www.neutron64.com/data-graph')


def request_ssl(ip):
  mutation = """mutation{
    startSslRequest(address: "{address}") {
      url
    }
  }
  """

  if ip is None:
    ip = '0.0.0.0'

  mutation = mutation.replace('{address}', ip)
  response = requests.post(URL, json={'query': mutation})
  return response.json()['data']['startSslRequest']['url']


def get_ssl(request_url, vcode):
  token = request_url.split('/')[-1]

  mutation = """mutation{
    getSsl(token:"{token}" vcode: "{vcode}"){
      domain
      chain
      privkey
    }
  }
  """
  mutation = mutation.replace('{token}', token)
  mutation = mutation.replace('{vcode}', vcode)

  response = requests.post(URL, json={'query': mutation})
  return response.json()['data']['getSsl']


def renew_ssl(domain, crt, key):
  mutation = """mutation{
    renewSsl(chain:{chain} privkey:{privkey} domain:{domain}){
      vcode
    }
  }
  """

  mutation = mutation.replace('{chain}', json.dumps(crt))
  mutation = mutation.replace('{privkey}', json.dumps(key))
  mutation = mutation.replace('{domain}', json.dumps(domain))

  response = requests.post(URL, json={'query': mutation})
  try:
    rdata = response.json()

  except:
    print(response.status_code, response.text)
    return

  if 'data' in rdata and 'renewSsl' in rdata['data'] and rdata['data']['renewSsl']:
    return rdata['data']['renewSsl']

  print(rdata['errors'][0]['message'])


def get_renewal(domain, vcode):
  mutation = """mutation{
    getRenewal(domain:{domain} vcode:{vcode}){
      chain
      privkey
      created
      expires
    }
  }
  """

  mutation = mutation.replace('{domain}', json.dumps(domain))
  mutation = mutation.replace('{vcode}', json.dumps(vcode))

  response = requests.post(URL, json={'query': mutation})
  try:
    rdata = response.json()

  except:
    print(response.status_code, response.text)
    return

  if 'data' in rdata and 'getRenewal' in rdata['data'] and rdata['data']['getRenewal']:
    return rdata['data']['getRenewal']

  print(rdata['errors'][0]['message'])
