import os
import pathlib
import shutil

import tornado.log
from binaryornot.helpers import is_binary_string

from nbeam.utils import valid_path, rel_path


def nbeam_add(request, settings):
  path = request['name']

  if 'parent' in request:
    path = os.path.join(request['parent'], path)

  path = valid_path(path, request, settings)

  if path:
    if os.path.exists(path):
      return {'error': 'Already exists.'}

    else:
      if request['is_dir']:
        os.mkdir(path)

      else:
        pathlib.Path(path).touch()

      stats = os.stat(path)
      return {
          'name': request['name'],
          'path': rel_path(path, request, settings),
          'id': stats.st_ino,
          'dir': request['is_dir'],
          'createdTime': stats.st_ctime,
          'modifiedTime': stats.st_mtime,
      }

  return {'error': 'Invalid path.'}


def nbeam_remove(request, settings):
  path = valid_path(request['path'], request, settings)
  if path:
    if os.path.isdir(path):
      shutil.rmtree(path)

    else:
      os.remove(path)

    return {'status': 'OK'}

  return {'error': 'Invalid path.'}


def nbeam_rename(request, settings):
  path = valid_path(request['path'], request, settings)

  if path:
    d = os.path.dirname(request['path'])
    new_path = os.path.join(d, request['name'])
    new_path = valid_path(new_path, request, settings)

    if new_path:
      os.rename(path, new_path)
      return {'path': rel_path(new_path, request, settings)}

  return {'error': 'Invalid path.'}


def nbeam_save(request, settings):
  path = valid_path(request['path'], request, settings)

  if path:
    fh = open(path, 'w')
    fh.write(request['contents'])
    fh.close()
    return {'status': 'OK'}

  return {'error': 'Invalid path.'}


def nbeam_open(request, settings):
  path = valid_path(request['path'], request, settings)

  if path:
    fh = open(path, 'rb')
    if is_binary_string(fh.read(512)):
      return {'error': 'Binary file.'}

    fh.seek(0)
    response = {'contents': fh.read().decode('utf-8')}
    fh.close()
    return response

  return {'error': 'Invalid path.'}


def nbeam_list(request, settings):
  w = int(request['workspace']) - 1
  folder = settings['workspaces'][w]

  if 'in_folder' in request and request['in_folder']:
    folder = request['in_folder']

  folder = valid_path(folder, request, settings)
  if folder:
    files = []

    for f in os.scandir(folder):
      try:
        stats = f.stat()
      except:
        continue

      files.append({
          'name': f.name,
          'path': rel_path(f.path, request, settings),
          'id': f.inode(),
          'dir': f.is_dir(),
          'createdTime': stats.st_ctime,
          'modifiedTime': stats.st_mtime,
      })

    return {'files': files}

  return {'error': 'Invalid path.'}
