import os
import signal

from tornado import gen
from tornado.log import logging
from terminado import NamedTermManager


class TerminalManager(NamedTermManager):

  def __init__(self, *args, **kwargs):
    super().__init__(*args, **kwargs)
    self.term_count = {}

  def kill_all(self, *args, **kwargs):
    super().kill_all(*args, **kwargs)
    self.term_count = {}

  def client_disconnected(self, websocket):
    logging.info('Client Disconnected')
    if websocket.terminal and websocket.settings['terminal']['timeout']:
      self.terminal_timeout(websocket.terminal,
                            websocket.settings['terminal']['timeout'])

  def get_terminal(self, term_name):
    term = super().get_terminal(term_name)

    if term_name in self.term_count:
      self.term_count[term_name] += 1

    else:
      self.term_count[term_name] = 1

    return term

  def do_kill(self, terminal):
    if os.name == 'nt':
      terminal.kill()
      # Immediately call the pty reader to process
      # the eof and free up space
      self.pty_read(terminal.ptyproc.fd)
      return

    terminal.killpg(signal.SIGHUP)

  @gen.coroutine
  def terminal_timeout(self, terminal, timeout):
    name = terminal.term_name
    self.term_count[name] -= 1

    yield gen.sleep(timeout)

    if self.term_count[name] < 1:
      logging.info('Timeout Terminating {}'.format(name))
      self.do_kill(terminal)

      del self.terminals[name]
      del self.term_count[name]
